@@ -41,7 +41,7 @@ class Bamboo(AtlassianRestAPI):
                 yield r
             start_index += results['max-result']
 
-    def base_list_call(self, resource, expand, favourite, clover_enabled, max_results, label, start_index=0, **kwargs):
+    def base_list_call(self, resource, expand, favourite, clover_enabled, max_results, label=None, start_index=0, **kwargs):
         flags = []
         params = {'max-results': max_results}
         if expand:
@@ -209,6 +209,25 @@ class Bamboo(AtlassianRestAPI):
         except ValueError:
             raise ValueError('The key "{}" does not correspond to the latest build result'.format(plan_key))
 
+    def delete_build_result(self, build_key):
+        """
+        Deleting result for specific build
+        :param build_key: Take full build key, example: PROJ-PLAN-8
+        """
+        custom_resource = '/build/admin/deletePlanResults.action'
+        build = build.split('-')
+        plan_key = '{}-{}'.format(build[0], build[1])
+        build_number = build[2]
+        params = {'buildKey': plan_key, 'buildNumber': build_number}
+        return self.post(custom_resource, params=params, headers=self.form_token_headers)
+    def delete_plan(self, plan_key):
+        """
+        Marks plan for deletion. Plan will be deleted by a batch job.
+        :param plan_key:
+        :return:
+        """
+        resource = 'rest/api/latest/plan/{}'.format(plan_key)
+        return self.delete(resource)
     def reports(self, max_results=25):
         params = {'max-results': max_results}
         return self._get_generator(self.resource_url('chart/reports'), elements_key='reports', element_key='report',
